Action

Enum Action 

#[repr(u8)]
pub enum Action {
Show 22 variants Click = 0, Focus = 1, Blur = 2, Collapse = 3, Expand = 4, CustomAction = 5, Decrement = 6, Increment = 7, HideTooltip = 8, ShowTooltip = 9, ReplaceSelectedText = 10, ScrollDown = 11, ScrollLeft = 12, ScrollRight = 13, ScrollUp = 14, ScrollIntoView = 15, ScrollToPoint = 16, SetScrollOffset = 17, SetTextSelection = 18, SetSequentialFocusNavigationStartingPoint = 19, SetValue = 20, ShowContextMenu = 21,
}
An action to be taken on an accessibility node.

Variants



Click = 0

Do the equivalent of a single click or tap.



Focus = 1



Blur = 2



Collapse = 3



Expand = 4



CustomAction = 5



Decrement = 6

Decrement a numeric value by one step.



Increment = 7

Increment a numeric value by one step.



HideTooltip = 8



ShowTooltip = 9



ReplaceSelectedText = 10

Delete any selected text in the control’s text value and insert the specified value in its place, like when typing or pasting. Requires ActionRequest::data to be set to ActionData::Value.



ScrollDown = 11

Scroll down by the specified unit.



ScrollLeft = 12

Scroll left by the specified unit.



ScrollRight = 13

Scroll right by the specified unit.



ScrollUp = 14

Scroll up by the specified unit.



ScrollIntoView = 15

Scroll any scrollable containers to make the target node visible. Optionally set ActionRequest::data to ActionData::ScrollHint.



ScrollToPoint = 16

Scroll the given object to a specified point in the tree’s container (e.g. window). Requires ActionRequest::data to be set to ActionData::ScrollToPoint.



SetScrollOffset = 17



SetTextSelection = 18



SetSequentialFocusNavigationStartingPoint = 19

Don’t focus this node, but set it as the sequential focus navigation starting point, so that pressing Tab moves to the next element following this one, for example.



SetValue = 20

Replace the value of the control with the specified value and reset the selection, if applicable. Requires ActionRequest::data to be set to ActionData::Value or ActionData::NumericValue.



ShowContextMenu = 21

Implementations

Source

impl Action

pub fn n(value: u8) -> Option<Self>

Source

impl Action

pub(crate) fn mask(self) -> u32